#!/bin/bash

SCRIPT_PATH="$( cd "$( dirname "${BASH_SOURCE[0]}" )" >/dev/null 2>&1 && pwd )"

CERT_FILE_PATH=$SCRIPT_PATH/imatest_ssl_cert.cer
LOG_FILE=$SCRIPT_PATH/jre_cert_store_update.log

if [[ $(id -u) -ne 0 ]] ; then
	echo "This script must be run as root. Please run sudo -H ./jre_cert_store_update.sh"
	exit 1
fi

function update(){
	local MATLAB_PATH=$1
	local CERT_FILE_PATH=$2
	local LOG_FILE=$3
	local MCR_ROOT=
	local CERT_STORE_PATH=
	local ARCH=glnxa64
	local OLD_PATH=$PATH
	local OLD_LD_LIBRARY_PATH=$LD_LIBRARY_PATH

	if [ -d $MATLAB_PATH ]; then
		for dir in $MATLAB_PATH/v*/
		do
			MCR_ROOT=${dir%*/}
			CERT_STORE_PATH=$MCR_ROOT/sys/java/jre/$ARCH/jre/lib/security/cacerts
			JRE_BIN=$MCR_ROOT/sys/java/jre/$ARCH/jre/bin
			JRE_LIB=$MCR_ROOT/sys/java/jre/$ARCH/jre/lib
			KEYTOOL=$JRE_BIN/keytool
			export PATH=$JRE_BIN:$OLD_PATH
			export LD_LIBRARY_PATH=$JRE_LIB:$OLD_LD_LIBRARY_PATH

			echo Updating certificate store for "$MCR_ROOT$" >> "$LOG_FILE"
			echo Certificate store path $CERT_STORE_PATH >> "$LOG_FILE"
			keytool -import -noprompt -trustcacerts -alias imatest -file $CERT_FILE_PATH -keystore $CERT_STORE_PATH -storepass changeit >> "$LOG_FILE"
		done
		
		echo ================== >> "$LOG_FILE"
		
		echo Certificate details >> "$LOG_FILE"
		echo Certificate file: $CERT_FILE_PATH
		keytool -printcert -file "$CERT_FILE_PATH" >> "$LOG_FILE"

		echo ==================================== >> "$LOG_FILE"
		

		export PATH=$OLD_PATH
		export LD_LIBRARY_PATH=$OLD_LD_LIBRARY_PATH
	fi
}



update "/Applications/MATLAB/MATLAB_Runtime/" $CERT_FILE_PATH $LOG_FILE

